==> wevue-1.2.8.tgz: package/lib/app.js <==
//读取app.json生成vue app框架
var path = require('path');
var fs = require('fs');
var fse = require('fs-extra');
var chalk = require('chalk');
var AppWxss = require('./app_wxss');
var AppConfig = require('./app_config');
var debug = require('debug')('wevue');


//拷Vue模板到.tmp目录
function CopyVueTemplateFolder(templateFolder, vueFolder) {
    var source, dest;
    try {
        var ingores = ['pages', 'app.js', 'app.json', 'app.css', 'node_modules', 'app-admin.css', 'app-admin.js', 'app-admin.json', 'backend.css', 'backend.vue', 'backend.js'];
        var folders = fs.readdirSync(templateFolder);
        for (var i = 0; i < folders.length; i++) {
            var source = path.join(templateFolder, folders[i]);
            var dest = path.join(vueFolder, folders[i]);
            if (folders[i] == 'src') {

                var srcFolders = fs.readdirSync(path.join(templateFolder, 'src'));
                for (var j = 0; j < srcFolders.length; j++) {
                    //过滤模板中不要的文件
                    if (ingores.indexOf(srcFolders[j]) < 0) {
                        source = path.join(templateFolder, 'src', srcFolders[j]);
                        dest = path.join(vueFolder, 'src', srcFolders[j]);
                        debug("copy template", source, dest);
                        fse.copySync(source, dest);
                    }
                }
            } else {
                if (ingores.indexOf(folders[i]) < 0) {
                    debug("copy template", source, dest);
                    fse.copySync(source, dest);
                }
            }
        }
    } catch (e) {
        console.log('CopyVueTemplateFolder error', source, dest);
        console.log(e.stack);
    } finally {

    }
}

//将小程序目录下的文件copy到.tmp src目录
function CopyWxFolder(weFolder, vueFolder, rootFolder, program) {
    var source,dest;
    try {
        var ingores = ['pages', '.tmp', '.wevue', 'app.wxss', 'app-admin.wxss', '.git', 'node_modules', 'backend.wxml', 'backend.wxss', program.output];
        debug('ingores', ingores);
        var folders = fs.readdirSync(weFolder);
        for (var i = 0; i < folders.length; i++) {
            source = path.join(weFolder, folders[i]);
            dest = path.join(vueFolder, 'src', folders[i]);
            debug("source", source);
            var folderName = folders[i];
            if (ingores.indexOf(folderName) < 0) {
                //所有的.*文件不能copy过去
                debug('folderName', folderName);
                fse.copySync(source, dest);
            }
        }
    } catch (e) {
        console.log('CopyWxFolder',source,dest);
        console.log(e.stack);
    } finally {

    }
}

function clearSrc(vueFolder) {
    try {
        var srcFolder=path.join(vueFolder, 'src');
        if (fs.existsSync(srcFolder)) {
            var folders = fs.readdirSync(srcFolder);
            for (var i = 0; i < folders.length; i++) {
                var source = path.join(vueFolder, 'src', folders[i]);
                fse.removeSync(source);
            }
        } else {
            if (!fs.existsSync(vueFolder)){
                fs.mkdirSync(vueFolder);
            }
        }
    } catch (e) {
        console.log(e.stack);
    } finally {

    }
}



module.exports = function(wefolder, vueFolder, rootFolder, wevueFolder, program) {
    //生成目录 将vue 目录 复制到 vueFolder下面

    debug(program.output);
    try {
        clearSrc(vueFolder);
        debug('clear', vueFolder);
        //copy vue folder
        console.log(process.execPath);


        var vueTemplateFolder = path.join(wevueFolder, 'vue');
        debug('copy vue folder ', vueTemplateFolder, vueFolder);

        CopyVueTemplateFolder(vueTemplateFolder, vueFolder, program);
        // copy wefolder without pages


        CopyWxFolder(wefolder, vueFolder, rootFolder, program);

        AppWxss(wefolder, vueFolder, rootFolder); //转换app.wxss

        AppConfig(wefolder, vueFolder, rootFolder, wevueFolder, program); //增加index.html中的config


    } catch (err) {
        console.log(chalk.red("生成h5目录出错"));
        console.error(err.stack);
    }
}

==> wevue-1.2.17.tgz: package/lib/app.js <==
//读取app.json生成vue app框架
var path = require('path');
var fs = require('fs');
var fse = require('fs-extra');
var chalk = require('chalk');
var AppWxss = require('./app_wxss');
var AppConfig = require('./app_config');
var debug = require('debug')('wevue');


//拷Vue模板到.tmp目录
function CopyVueTemplateFolder(templateFolder, vueFolder) {
    var source, dest;
    try {
        var ingores = ['pages', 'app.js', 'app.json', 'app.css', 'node_modules', 'app-admin.css',
         'app-admin.js', 'app-admin.json', 'backend.css', 'backend.vue', 'backend.js'];
        var folders = fs.readdirSync(templateFolder);
        for (var i = 0; i < folders.length; i++) {
            var source = path.join(templateFolder, folders[i]);
            var dest = path.join(vueFolder, folders[i]);
            if (folders[i] == 'src') {

                var srcFolders = fs.readdirSync(path.join(templateFolder, 'src'));
                for (var j = 0; j < srcFolders.length; j++) {
                    //过滤模板中不要的文件
                    if (ingores.indexOf(srcFolders[j]) < 0) {
                        source = path.join(templateFolder, 'src', srcFolders[j]);
                        dest = path.join(vueFolder, 'src', srcFolders[j]);
                        debug("copy template", source, dest);
                        fse.copySync(source, dest);
                    }
                }
            } else {
                if (ingores.indexOf(folders[i]) < 0) {
                    debug("copy template", source, dest);
                    fse.copySync(source, dest);
                }
            }
        }
    } catch (e) {
        console.log('CopyVueTemplateFolder error', source, dest);
        console.log(e.stack);
    } finally {

    }
}

//将小程序目录下的文件copy到.tmp src目录
function CopyWxFolder(weFolder, vueFolder, rootFolder, program) {
    var source,dest;
    try {
        var ingores = ['pages', '.tmp', '.wevue', 'app.wxss', 'app-admin.wxss', '.git', 'node_modules', 'backend.wxml', 'backend.wxss', program.output];
        debug('ingores', ingores);
        var folders = fs.readdirSync(weFolder);
        for (var i = 0; i < folders.length; i++) {
            source = path.join(weFolder, folders[i]);
            dest = path.join(vueFolder, 'src', folders[i]);
            debug("source", source);
            var folderName = folders[i];
            if (ingores.indexOf(folderName) < 0) {
                //所有的.*文件不能copy过去
                debug('folderName', folderName);
                fse.copySync(source, dest);
            }
        }
    } catch (e) {
        console.log('CopyWxFolder',source,dest);
        console.log(e.stack);
    } finally {

    }
}

function clearSrc(vueFolder) {
    try {
        var srcFolder=path.join(vueFolder, 'src');
        if (fs.existsSync(srcFolder)) {
            var folders = fs.readdirSync(srcFolder);
            for (var i = 0; i < folders.length; i++) {
                var source = path.join(vueFolder, 'src', folders[i]);
                fse.removeSync(source);
            }
        } else {
            if (!fs.existsSync(vueFolder)){
                fs.mkdirSync(vueFolder);
            }
        }
    } catch (e) {
        console.log(e.stack);
    } finally {

    }
}



module.exports = function(wefolder, vueFolder, rootFolder, wevueFolder, program) {
    //生成目录 将vue 目录 复制到 vueFolder下面

    debug(program.output);
    try {
        clearSrc(vueFolder);
        debug('clear', vueFolder);
        //copy vue folder
        console.log(process.execPath);


        var vueTemplateFolder = path.join(wevueFolder, 'vue');
        debug('copy vue folder ', vueTemplateFolder, vueFolder);

        CopyVueTemplateFolder(vueTemplateFolder, vueFolder, program);
        // copy wefolder without pages


        CopyWxFolder(wefolder, vueFolder, rootFolder, program);

        AppWxss(wefolder, vueFolder, rootFolder); //转换app.wxss

        AppConfig(wefolder, vueFolder, rootFolder, wevueFolder, program); //增加index.html中的config


    } catch (err) {
        console.log(chalk.red("生成h5目录出错"));
        console.error(err.stack);
    }
}
